]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - lib.sh
lib.sh: Documentation fix.
[config/dotfiles.git] / lib.sh
diff --git a/lib.sh b/lib.sh
index ea61359e2e806be5b26aaff201930743d7214b5a..e9fd56dbed9facaa46da77390a738d922989db4a 100644 (file)
--- a/lib.sh
+++ b/lib.sh
@@ -7,9 +7,6 @@
 # options supported by zsh or GNU ls.
 unset LS_COLORS
 
-# Get path to m4 because it's later redefined as function.
-m4=`which m4`
-
 
 # Check if the given program is installed. Returns 0 if it exists, 1
 # otherwise; so it can be used in if.
@@ -17,11 +14,14 @@ installed() {
     which $1 | grep -E '^/' > /dev/null
 }
 
# Prints the current OS. Supported are Debian (debian) and Mac OS X (darwin)
# at the moment. If an unsupported OS is used an error is printed.
 os() {
     if [ -f /etc/debian_version ]; then
         echo debian
+    elif [ -f /etc/gentoo-release ]; then
+        echo gentoo
     elif [ x`uname` = xDarwin ]; then
         echo darwin
     else
@@ -69,26 +69,66 @@ link() {
     unset pwd base source target
 }
 
-# m4 wrapper which uses $1.m4 as template file, feeds it to m4 and writes it
-# to $1 with a warning at the beginning to not edit the generated file.
+# Write a warning to $1 to make clear it should not be modified. $2 is the
+# source for the generated file. Also print a message to stdout that the file
+# $1 was generated from $2 using the command $3 with options $4.
+warning() {
+    echo "###################################" > $1
+    echo "# WARNING! DO NOT EDIT THIS FILE! #" >> $1
+    echo "###################################" >> $1
+    echo >> $1
+    echo "# It was generated from $2 on `date`." >> $1
+    echo >> $1
+
+    # Display given options if there were any (zsh has a problem with $options
+    # as variable name).
+    option=
+    if [ -n "$4" ]; then
+        option=" with options '$4'"
+    fi
+    # Write message to stdout.
+    echo "$3: generating '$1' from '$2'$option"
+
+    unset option
+}
+
+# Generate a file using several methods. A warning not to edit it is
+# automatically added to the created file and a message printed to stdout
+# through warning().
 #
-# All arguments (except the first which is the filename) are passed to m4.
-m4() {
-    # First argument is file name.
-    file=$1
+# The following commands are possible; the file extension for the source file
+# in brackets.
+#
+# - m4  (.m4): pipe $2.m4 through m4 then write it to $2
+# - awk (.in): pipe $2.in through awk then write it to $2
+# - cat ($3):  copy $2$3 to $2
+generate() {
+    # Get command and target file.
+    command="$1"
+    file="$2"
+    # Remove arguments from list.
+    shift
     shift
 
-    # Write a warning to the generated file.
-    echo "###################################" > $file
-    echo "# WARNING! DO NOT EDIT THIS FILE! #" >> $file
-    echo "###################################" >> $file
-    echo >> $file
-    echo "# It was generated from $file.m4 on `date`." >> $file
-    echo >> $file
+    # Set extension for the used commands. When cat is used $3 is used as
+    # extension.
+    if [ x"$command" = xm4 ]; then
+        extension=.m4
+    elif [ x"$command" = xawk ]; then
+        extension=.in
+    elif [ x"$command" = xcat ]; then
+        extension="$1" # is $3 in reality, $1 because of shifting
+        shift
+    # Print a warning and exit if an unsupported command is used.
+    else
+        echo "generate(): command '$command' not supported!" >&2
+        exit 1
+    fi
 
-    # Process $1.m4 with m4 using the given options.
-    echo "m4(): generating '$file' from '$file.m4' with options '$*'"
-    $m4 $* $file.m4 >> $file
+    # Add warning to file and write a message to stdout.
+    warning "$file" "$file$extension" $command "$*"
+    # Generate $file from $file$extension using the given command.
+    cat "$file$extension" | $command "$@" >> "$file"
 
-    unset file
+    unset command file
 }
@@ -17,11 +14,14 @@ installed() {
 }
 
-# Prints the current OS. Supported are Debian (debian) and Mac OS X (darwin)
-# at the moment. If an unsupported OS is used an error is printed.
+# Prints the current OS. Supported are Debian (debian), Gentoo (gentoo) and
+# Mac OS X (darwin) at the moment. If an unsupported OS is used an error is
+# printed.
 os() {
     if [ -f /etc/debian_version ]; then